<?php
/*
Plugin Name: Pneuma Theme Image Cover Widget
Description: Allows you to have an image with hover text like the podcast series.
Version: 1.0.0
Author: Organized Themes
Author URI: http://www.organizedthemes.com
*/


class ImageCoverWidget extends WP_Widget {
 /**
  * Declares the ImageCoverWidget class.
  *
  */
	
	function __construct() {
	 		parent::__construct(
	 			'imagecover', // Base ID
	 			__( 'Image Cover', 'pneuma' ), // Name
	 			array( 
	 				'description' => __( 'Display an image with hover text and link.', 'pneuma' ),
					'classname' => 'image-cover',
				)
			);
		}

  /**
    * Displays the Widget
    *
    */
	public function widget($args, $instance){
		extract($args);
		$title = empty($instance['title']) ? '' : $instance['title'];
		$image_url = empty($instance['image_url']) ? '' : $instance['image_url'];
		$link_url = empty($instance['link_url']) ? '' : $instance['link_url'];
		
		# Before the widget
		echo $before_widget;
		
		# Make the widget
		
		?>
		
		<ul class="podcast-series clearfix image-cover">
		
			<li class="podcast-series-item">
			
				<a href="<?php echo $link_url; ?>">
				
					<img src="<?php echo $image_url; ?>" alt="" />
				
					<div class="series-title"><h3><?php echo $title; ?></h3></div>
				
				</a>
			
			</li>
		
		</ul>
		
		<?php
		
		# After the widget
		echo $after_widget;
	}

  /**
    * Saves the widgets settings.
    *
    */
	public function update($new_instance, $old_instance){
		$instance = $old_instance;
		$instance['title'] = stripslashes($new_instance['title']);
		$instance['image_url'] = stripslashes($new_instance['image_url']);
		$instance['link_url'] = stripslashes($new_instance['link_url']);
		
		return $instance;
	}

  /**
    * Creates the edit form for the widget.
    *
    */
    public function form($instance){
      //Defaults
      $instance = wp_parse_args( (array) $instance, array(
      		'title'		=> '',
      		'image_url' => '',
      		'link_url'	=> ''
      	) 
      );

	?>
	
	<p>
		<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title', 'pneuma'); ?>:</label>
		<input type="text" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" style="width:99%;" />
	</p>
	<p>
		<label for="<?php echo $this->get_field_id('image_url'); ?>"><?php _e('Image File URL', 'pneuma'); ?>:</label>
		<input type="text" id="<?php echo $this->get_field_id('image_url'); ?>" name="<?php echo $this->get_field_name('image_url'); ?>" value="<?php echo esc_attr( $instance['image_url'] ); ?>" style="width:99%;" /><br />
		
		Enter the URL to your image file here.  You can find that URL by selecting an image in your media library.  The URL will be listed there for you to copy and paste.
	</p>
	
	<p>
		<label for="<?php echo $this->get_field_id('link_url'); ?>"><?php _e('Link URL', 'pneuma'); ?>:</label>
		<input type="text" id="<?php echo $this->get_field_id('link_url'); ?>" name="<?php echo $this->get_field_name('link_url'); ?>" value="<?php echo esc_attr( $instance['link_url'] ); ?>" style="width:99%;" />
	</p>
	
      
<?php
  }

}// END class

function ImageCoverWidgetInit() {
	register_widget('ImageCoverWidget');
}
add_action('widgets_init', 'ImageCoverWidgetInit');
